==> scanbot_sdk-2.13.0-alpha01.tar.gz: lib/classical_components/medical_certificate_scanner_configuration.dart <==
import 'package:json_annotation/json_annotation.dart';

import 'camera_configuration.dart';

export 'camera_configuration.dart';
export 'finder.dart';
part 'medical_certificate_scanner_configuration.g.dart';

@JsonSerializable(
    createFactory: false, includeIfNull: false, explicitToJson: true)
class MedicalCertificateCameraConfiguration extends CameraConfiguration {
  /// Controls whether the flash should be initially enabled.
  /// The default value is FALSE.
  bool? flashEnabled;

  ///Set current zoom by a linear zoom value ranging from 0f to 1.0f. Optical Zoom Level 0f represents the minimum zoom while Optical Zoom Level 1.0f represents the maximum zoom.
  ///Default value is 0f.
  double? cameraZoomFactor;

  @override
  @JsonKey(name: "detectorType")
  final DetectorType detectorType = DetectorType.mc;

  FinderConfiguration? finder;

  MedicalCertificateClassicScannerConfiguration scannerConfiguration;

  MedicalCertificateCameraConfiguration({
    required this.scannerConfiguration,
    this.flashEnabled,
    this.finder,
    this.cameraZoomFactor,
  });

  @override
  Map<String, dynamic> toJson() =>
      _$MedicalCertificateCameraConfigurationToJson(this);
}

@JsonSerializable(
    createFactory: false, includeIfNull: false, explicitToJson: true)
class MedicalCertificateClassicScannerConfiguration {
  @JsonKey(name: "detectorType")
  final DetectorType detectorType = DetectorType.mc;

  /// Recognition of Patient Information block. [true] if enabled
  bool recognizePatientInfo;

  ///Reading data from barcode, if it's present on document, could make data recognition more accurate. [true] if enabled.
  bool recognizeBarcode;

  ///Make high-res snapshot of the image after first successfull medical certificate detection and recognise medical certificate fields on it
  bool captureHighResolutionImage;

  MedicalCertificateClassicScannerConfiguration(
      {this.recognizePatientInfo = true,
      this.recognizeBarcode = true,
      this.captureHighResolutionImage = false});

  Map<String, dynamic> toJson() =>
      _$MedicalCertificateClassicScannerConfigurationToJson(this);
}

==> scanbot_sdk-2.13.3-alpha01.tar.gz: lib/classical_components/medical_certificate_scanner_configuration.dart <==
import 'package:json_annotation/json_annotation.dart';

import 'camera_configuration.dart';

export 'camera_configuration.dart';
export 'finder.dart';
part 'medical_certificate_scanner_configuration.g.dart';

@JsonSerializable(
    createFactory: false, includeIfNull: false, explicitToJson: true)
class MedicalCertificateCameraConfiguration extends CameraConfiguration {
  /// Controls whether the flash should be initially enabled.
  /// The default value is FALSE.
  bool? flashEnabled;

  /// Set current zoom by a linear zoom value ranging from 0f to 1.0f. Optical Zoom Level 0f represents the minimum zoom while Optical Zoom Level 1.0f represents the maximum zoom.
  /// Default value is 0f.
  double? cameraZoomFactor;

  @override
  @JsonKey(name: "detectorType")
  final DetectorType detectorType = DetectorType.mc;

  FinderConfiguration? finder;

  MedicalCertificateClassicScannerConfiguration scannerConfiguration;

  MedicalCertificateCameraConfiguration({
    required this.scannerConfiguration,
    this.flashEnabled,
    this.finder,
    this.cameraZoomFactor,
  });

  @override
  Map<String, dynamic> toJson() =>
      _$MedicalCertificateCameraConfigurationToJson(this);
}

@JsonSerializable(
    createFactory: false, includeIfNull: false, explicitToJson: true)
class MedicalCertificateClassicScannerConfiguration {
  @JsonKey(name: "detectorType")
  final DetectorType detectorType = DetectorType.mc;

  /// Recognition of Patient Information block. true if enabled
  bool recognizePatientInfo;

  /// Reading data from barcode, if it's present on document, could make data recognition more accurate. true if enabled.
  bool recognizeBarcode;

  /// Make high-res snapshot of the image after first successful medical certificate detection and recognise medical certificate fields on it
  bool captureHighResolutionImage;

  MedicalCertificateClassicScannerConfiguration(
      {this.recognizePatientInfo = true,
      this.recognizeBarcode = true,
      this.captureHighResolutionImage = false});

  Map<String, dynamic> toJson() =>
      _$MedicalCertificateClassicScannerConfigurationToJson(this);
}
